@@ -12,7 +12,7 @@ use File::Find;
 use IO::File;
 use Archive::Tar;
 
-our $VERSION = version->declare("v2.17.17");
+our $VERSION = version->declare("v2.18.19");
 
 our @EXPORT_OK = qw(
     backup
@@ -222,7 +222,7 @@ Dev::Util::Backup - backup functions
 
 =head1 VERSION
 
-Version v2.17.17
+Version v2.18.19
 
 =head1 SYNOPSIS
 
@@ -291,14 +291,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Dev-Util>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Dev-Util>
-
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Dev-Util>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Dev-Util>
